@@ -18,7 +18,7 @@ functions = ('gaussian', 'lorentzian', 'voigt', 'pvoigt', 'moffat', 'pearson7',
              'students_t', 'expgaussian', 'donaich', 'skewed_gaussian',
              'skewed_voigt', 'step', 'rectangle', 'erf', 'erfc', 'wofz',
              'gamma', 'gammaln', 'exponential', 'powerlaw', 'linear',
-             'parabolic', 'sine', 'expsine')
+             'parabolic', 'sine', 'expsine', 'split_lorentzian')
 
 
 def gaussian(x, amplitude=1.0, center=0.0, sigma=1.0):
@@ -41,6 +41,25 @@ def lorentzian(x, amplitude=1.0, center=0.0, sigma=1.0):
     return (amplitude/(1 + ((1.0*x-center)/sigma)**2)) / (pi*sigma)
 
 
+def split_lorentzian(x, amplitude=1.0, center=0.0, sigma=1.0, sigma_r=1.0):
+    """Return a 1-dimensional piecewise Lorentzian function.
+
+    Split means that width of the function is different between
+    left and right slope of the function. The peak height is calculated
+    from the condition that the integral from ``-.inf`` to ``+.inf`` is equal
+    to ``amplitude``.
+
+    split_lorentzian(x, amplitude, center, sigma, sigma_r) =
+        amplitude * 2 / pi / (sigma + sigma_r) * \
+        (1 / (1 + ((x - center) / sigma)**2) * (x < center)
+         + 1 / (1 + ((x - center) / sigma_r)**2) * (x >= center))
+
+    """
+    return amplitude * 2 / pi / (sigma + sigma_r) * \
+        (1 / (1 + ((x - center) / sigma)**2) * (x < center)
+         + 1 / (1 + ((x - center) / sigma_r)**2) * (x >= center))
+
+
 def voigt(x, amplitude=1.0, center=0.0, sigma=1.0, gamma=None):
     """Return a 1-dimensional Voigt function.
 
@@ -60,7 +79,7 @@ def pvoigt(x, amplitude=1.0, center=0.0, sigma=1.0, fraction=0.5):
     """Return a 1-dimensional pseudo-Voigt function.
 
     pvoigt(x, amplitude, center, sigma, fraction) =
-       amplitude*(1-fraction)*gaussion(x, center, sigma_g) +
+       amplitude*(1-fraction)*gaussian(x, center, sigma_g) +
        amplitude*fraction*lorentzian(x, center, sigma)
 
     where sigma_g (the sigma for the Gaussian component) is
