@@ -35,6 +35,7 @@ import uncertainties
 
 from ._ampgo import ampgo
 from .parameter import Parameter, Parameters
+from .printfuncs import fitreport_html_table
 
 # check for EMCEE
 try:
@@ -102,8 +103,7 @@ def eval_stderr(obj, uvars, _names, _pars):
     uval = wrap_ueval(*uvars, _obj=obj, _names=_names, _pars=_pars)
     try:
         obj.stderr = uval.std_dev
-    # TODO: do not use bare except
-    except:
+    except Exception:
         obj.stderr = 0
 
 
@@ -350,6 +350,11 @@ class MinimizerResult(object):
         self.aic = _neg2_log_likel + 2 * self.nvarys
         self.bic = _neg2_log_likel + np.log(self.ndata) * self.nvarys
 
+    def _repr_html_(self, show_correl=True, min_correl=0.1):
+        """Returns a HTML representation of parameters data."""
+        return fitreport_html_table(self, show_correl=show_correl,
+                                    min_correl=min_correl)
+
 
 class Minimizer(object):
     """A general minimizer for curve fitting and optimization."""
@@ -869,8 +874,9 @@ class Minimizer(object):
         fmin_kws.update(kws)
 
         # hess supported only in some methods
-        if 'hess' in fmin_kws and method not in ('Newton-CG',
-                                                 'dogleg', 'trust-ncg'):
+        if 'hess' in fmin_kws and method not in ('Newton-CG', 'dogleg',
+                                                 'trust-constr', 'trust-ncg',
+                                                 'trust-krylov', 'trust-exact'):
             fmin_kws.pop('hess')
 
         # jac supported only in some methods (and Dfun could be used...)
@@ -879,10 +885,17 @@ class Minimizer(object):
             fmin_kws['jac'] = self.__jacobian
 
         if 'jac' in fmin_kws and method not in ('CG', 'BFGS', 'Newton-CG',
-                                                'dogleg', 'trust-ncg'):
+                                                'L-BFGS-B', 'TNC', 'SLSQP',
+                                                'dogleg', 'trust-ncg',
+                                                'trust-krylov', 'trust-exact'):
             self.jacfcn = None
             fmin_kws.pop('jac')
 
+        # workers / updating keywords only supported in differential_evolution
+        for kwd in ('workers', 'updating'):
+            if kwd in fmin_kws and method != 'differential_evolution':
+                fmin_kws.pop(kwd)
+
         if method == 'differential_evolution':
             for par in params.values():
                 if (par.vary and
@@ -894,15 +907,24 @@ class Minimizer(object):
             kwargs = dict(args=(), strategy='best1bin', maxiter=None,
                           popsize=15, tol=0.01, mutation=(0.5, 1),
                           recombination=0.7, seed=None, callback=None,
-                          disp=False, polish=True, init='latinhypercube')
+                          disp=False, polish=True, init='latinhypercube',
+                          atol=0, updating='immediate', workers=1)
 
             for k, v in fmin_kws.items():
                 if k in kwargs:
                     kwargs[k] = v
+
+            # keywords 'updating' and 'workers' are introduced in SciPy v1.2
+            # FIXME: remove after updating the requirement >= 1.2
+            if int(major) == 0 or (int(major) == 1 and int(minor) < 2):
+                kwargs.pop('updating')
+                kwargs.pop('workers')
+
             try:
                 ret = differential_evolution(self.penalty, _bounds, **kwargs)
             except AbortFitException:
                 pass
+
         else:
             try:
                 ret = scipy_minimize(self.penalty, variables, **fmin_kws)
@@ -1378,6 +1400,12 @@ class Minimizer(object):
         except AbortFitException:
             pass
 
+        # note: upstream least_squares is actually returning
+        # "last evaluation", not "best result", but we do this
+        # here for consistency, and assuming it will be fixed.
+        if not result.aborted:
+            result.residual = self.__residual(ret.x, False)
+            result.nfev -= 1
         result._calculate_statistics()
 
         if not result.aborted:
@@ -1462,11 +1490,13 @@ class Minimizer(object):
 
         try:
             lsout = scipy_leastsq(self.__residual, variables, **lskws)
-            _best, _cov, infodict, errmsg, ier = lsout
-            result.residual = infodict['fvec']
         except AbortFitException:
             pass
 
+        if not result.aborted:
+            _best, _cov, infodict, errmsg, ier = lsout
+            result.residual = self.__residual(_best)
+            result.nfev -= 1
         result._calculate_statistics()
 
         if result.aborted:
@@ -1537,13 +1567,6 @@ class Minimizer(object):
         basinhopping_kws.update(self.kws)
         basinhopping_kws.update(kws)
 
-        # FIXME - remove after requirement for scipy >= 0.19
-        major, minor, micro = scipy_version.split('.', 2)
-        if int(major) < 1 and int(minor) < 19:
-            _ = basinhopping_kws.pop('seed')
-            print("Warning: basinhopping doesn't support argument 'seed' for "
-                  "scipy versions below 0.19!")
-
         x0 = result.init_vals
 
         try:
@@ -2077,6 +2100,9 @@ def validate_nan_policy(policy):
     policy = policy.lower()
     if policy == 'drop':
         policy = 'omit'
+        warnings.warn("The option 'drop' is deprecated as of lmfit 0.9.13 and "
+                      "will be removed in the next release. Use 'omit' "
+                      "instead.", FutureWarning)
     if policy == 'none':
         policy = 'propagate'
     if policy not in VALID_NAN_POLICIES:
