@@ -14,8 +14,8 @@ from scipy.stats import t
 from . import Minimizer, Parameter, Parameters, lineshapes
 from .confidence import conf_interval
 from .jsonutils import HAS_DILL, decode4js, encode4js
-from .minimizer import validate_nan_policy
-from .printfuncs import ci_report, fit_report
+from .minimizer import validate_nan_policy, MinimizerResult
+from .printfuncs import ci_report, fit_report, fitreport_html_table
 
 # Use pandas.isnull for aligning missing data if pandas is available.
 # otherwise use numpy.isnan
@@ -36,7 +36,7 @@ def _align(var, mask, data):
 
 
 try:
-    from matplotlib import pyplot as plt
+    import matplotlib  # noqa: F401
     _HAS_MATPLOTLIB = True
 except Exception:
     _HAS_MATPLOTLIB = False
@@ -273,6 +273,9 @@ class Model(object):
         self._func_haskeywords = False
         if missing is not None:
             nan_policy = missing
+            warnings.warn("The keyword 'missing' is deprecated as of lmfit "
+                          "0.9.13 and will be removed in the next release. "
+                          "Use 'nan_policy' instead.", FutureWarning)
         self.nan_policy = validate_nan_policy(nan_policy)
 
         self.opts = kws
@@ -1256,9 +1259,6 @@ def load_modelresult(fname, funcdefs=None):
     modres = ModelResult(Model(lambda x: x, None), params)
     with open(fname) as fh:
         mresult = modres.load(fh, funcdefs=funcdefs)
-        mresult.data = mresult.userargs[0]
-        mresult.weights = mresult.userargs[1]
-        mresult.init_params = mresult.model.make_params(**mresult.init_values)
     return mresult
 
 
@@ -1565,6 +1565,13 @@ class ModelResult(Minimizer):
         modname = self.model._reprstring(long=True)
         return '[[Model]]\n    %s\n%s\n' % (modname, report)
 
+    def _repr_html_(self, show_correl=True, min_correl=0.1):
+        """Returns a HTML representation of parameters data."""
+        report = fitreport_html_table(self, show_correl=show_correl,
+                                      min_correl=min_correl)
+        modname = self.model._reprstring(long=True)
+        return "<h2> Model</h2> %s %s" % (modname, report)
+
     def dumps(self, **kws):
         """Represent ModelResult as a JSON string.
 
@@ -1679,6 +1686,13 @@ class ModelResult(Minimizer):
             setattr(self, attr, decode4js(modres.get(attr, None)))
 
         self.best_fit = self.model.eval(self.params, **self.userkws)
+        if len(self.userargs) == 2:
+            self.data = self.userargs[0]
+            self.weights = self.userargs[1]
+        self.init_params = self.model.make_params(**self.init_values)
+        self.result = MinimizerResult()
+        self.result.params = self.params
+        self.init_vals = list(self.init_values.items())
         return self
 
     def load(self, fp, funcdefs=None, **kws):
@@ -1779,6 +1793,7 @@ class ModelResult(Minimizer):
         ModelResult.plot : Plot the fit results and residuals using matplotlib.
 
         """
+        from matplotlib import pyplot as plt
         if data_kws is None:
             data_kws = {}
         if fit_kws is None:
@@ -1897,6 +1912,7 @@ class ModelResult(Minimizer):
         ModelResult.plot : Plot the fit results and residuals using matplotlib.
 
         """
+        from matplotlib import pyplot as plt
         if data_kws is None:
             data_kws = {}
         if fit_kws is None:
@@ -2014,6 +2030,7 @@ class ModelResult(Minimizer):
         ModelResult.plot_residuals : Plot the fit residuals using matplotlib.
 
         """
+        from matplotlib import pyplot as plt
         if data_kws is None:
             data_kws = {}
         if fit_kws is None:
