@@ -11,6 +11,7 @@ import scipy.special
 import uncertainties
 
 from .jsonutils import decode4js, encode4js
+from .printfuncs import params_html_table
 
 SCIPY_FUNCTIONS = {'gamfcn': scipy.special.gamma}
 for name in ('erf', 'erfc', 'wofz'):
@@ -190,8 +191,8 @@ class Parameters(OrderedDict):
     def update_constraints(self):
         """Update all constrained parameters, checking that dependencies are
         evaluated as needed."""
-        requires_update = set(name for name, par in self.items()
-                              if par._expr is not None)
+        requires_update = {name for name, par in self.items() if par._expr is
+                           not None}
         updated_tracker = set(requires_update)
 
         def _update_param(name):
@@ -284,6 +285,10 @@ class Parameters(OrderedDict):
             print(line.format(name_len=name_len, n=colwidth, p=precision,
                               f=fmt, **pvalues))
 
+    def _repr_html_(self):
+        """Returns a HTML representation of parameters data."""
+        return params_html_table(self)
+
     def add(self, name, value=None, vary=True, min=-inf, max=inf, expr=None,
             brute_step=None):
         """Add a Parameter.
